# envelope — features


本 domain 下的所有功能：

- ✅ [FEAT-011 envelope-state](./FEAT-011-envelope-state.md) — done
- ✅ [FEAT-012 envelope-buy-mock](./FEAT-012-envelope-buy-mock.md) — done
- 📋 [FEAT-013 envelope-buy-real](./FEAT-013-envelope-buy-real.md) — planned
